$ContractActionCopyWith<T> class abstract

Inheritance

Constructors

$ContractActionCopyWith()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({FhirString? id, List<FhirExtension>? extension_, List<FhirExtension>? modifierExtension, FhirBoolean? doNotPerform, CodeableConcept? type, List<ContractSubject>? subject, CodeableConcept? intent, List<FhirString>? linkId, CodeableConcept? status, Reference? context, List<FhirString>? contextLinkId, OccurrenceXContractAction? occurrenceX, List<Reference>? requester, List<FhirString>? requesterLinkId, List<CodeableConcept>? performerType, CodeableConcept? performerRole, Reference? performer, List<FhirString>? performerLinkId, List<CodeableConcept>? reasonCode, List<Reference>? reasonReference, List<FhirString>? reason, List<FhirString>? reasonLinkId, List<Annotation>? note, List<FhirUnsignedInt>? securityLabelNumber, bool? disallowExtensions}) → T
The call method uses parameters of type Object? with a default value of fhirSentinel so that omitted parameters retain the sentinel value while explicit nulls do not.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited