ClinicalUseDefinition class

ClinicalUseDefinition A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.

Inheritance
Available extensions

Constructors

ClinicalUseDefinition({FhirString? id, FhirMeta? meta, FhirUri? implicitRules, CommonLanguages? language, Narrative? text, List<Resource>? contained, List<FhirExtension>? extension_, List<FhirExtension>? modifierExtension, List<Identifier>? identifier, required ClinicalUseDefinitionType type, List<CodeableConcept>? category, List<Reference>? subject, CodeableConcept? status, ClinicalUseDefinitionContraindication? contraindication, ClinicalUseDefinitionIndication? indication, ClinicalUseDefinitionInteraction? interaction, List<Reference>? population, ClinicalUseDefinitionUndesirableEffect? undesirableEffect, ClinicalUseDefinitionWarning? warning})
Primary constructor for ClinicalUseDefinition
const
ClinicalUseDefinition.fromJson(Map<String, dynamic> json)
Factory constructor that accepts Map<String, dynamic> as an argument
factory
ClinicalUseDefinition.fromJsonString(String source)
Factory constructor for ClinicalUseDefinition that takes in a String Convenience method to avoid the json Encoding/Decoding normally required to get data from a String
factory
ClinicalUseDefinition.fromYaml(dynamic yaml)
Deserialize ClinicalUseDefinition from a String or YamlMap object
factory

Properties

category List<CodeableConcept>?
category A categorisation of the issue, primarily for dividing warnings into subject heading areas such as "Pregnancy and Lactation", "Overdose", "Effects on Ability to Drive and Use Machines".
final
contained List<Resource>?
These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, and nor can they have their own independent transaction scope
finalinherited
contraindication ClinicalUseDefinitionContraindication?
contraindication Specifics for when this is a contraindication.
final
copyWith $ClinicalUseDefinitionCopyWith<ClinicalUseDefinition>
Copy function for ClinicalUseDefinition Returns a copy of the current instance with the provided fields modified. If a field is not provided, it will retain its original value. If a null is provided, this will clearn the field, unless the field is required, in which case it will keep its current value.
no setteroverride
copyWith $ClinicalUseDefinitionCopyWith<ClinicalUseDefinition>

Available on ClinicalUseDefinition, provided by the ClinicalUseDefinitionCopyWithExtension extension

no setter
extension_ List<FhirExtension>?
May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.",
finalinherited
fhirType String
Returns the FHIR type of the object.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasPrimitiveValue bool
Checks if the object has a primitive value.
no setterinherited
id FhirString?
The logical id of the resource, as used in the URL for the resource.
finalinherited
identifier List<Identifier>?
identifier Business identifier for this issue.
final
implicitRules FhirUri?
A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
finalinherited
indication ClinicalUseDefinitionIndication?
indication Specifics for when this is an indication.
final
interaction ClinicalUseDefinitionInteraction?
interaction Specifics for when this is an interaction.
final
isMetadataBased bool
All FhirBases and Resources are NOT metadata based
no setterinherited
isPrimitive bool
Checks if the object is primitive.
no setterinherited
language CommonLanguages?
The base language in which the resource is written. This should be the language of the text value in the content element when a text value is present.
finalinherited
meta FhirMeta?
The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
finalinherited
modifierExtension List<FhirExtension>?
May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element\u0027s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.\n\nModifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).",
finalinherited
path String
Local Reference for this Resource, form is "ResourceType/Id"
no setterinherited
population List<Reference>?
population The population group to which this applies.
final
primitiveValue String?
Retrieves the primitive value of the object.
no setterinherited
resourceType R4ResourceType
The type of resource
finalinherited
resourceTypeString String
produce a string of the resourceType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CodeableConcept?
status Whether this is a current issue or one that has been retired etc.
final
subject List<Reference>?
subject The medication or procedure for which this is an indication.
final
text Narrative?
A human-readable summary of the resource conveying the essential clinical and business information for the resource.",
finalinherited
thisReference Reference
Convenience method to return a Reference referring to that Resource
no setterinherited
type ClinicalUseDefinitionType
type indication | contraindication | interaction | undesirable-effect | warning.
final
undesirableEffect ClinicalUseDefinitionUndesirableEffect?
undesirableEffect Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
final
warning ClinicalUseDefinitionWarning?
warning A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'.
final

Methods

clone() ClinicalUseDefinition
Subclasses must implement the clone method.
override
compareDeep(FhirBase? e1, FhirBase? e2, [bool allowNull = false]) bool
Compares two FhirBase objects deeply using JSON comparison. This method converts both objects to JSON and compares the resulting structures, which catches all differences including those in nested objects.
inherited
compareDeepLists<T extends FhirBase>(List<T>? e1, List<T>? e2, bool allowNull) bool
Compares two lists with optional null/empty handling.
inherited
compareDeepStrings(String? s1, String? s2, bool allowNull) bool
Checks if the object is equal to another object.
inherited
equalsDeep(FhirBase? o) bool
Performs a deep comparison between two instances.
override
equalsDeepWithNull(FhirBase? obj1, FhirBase? obj2) bool
Deeply compares two FhirBase objects, either of which can be null. This is a convenience method that handles null checking before calling equalsDeep.
inherited
getChildByName(String name) FhirBase?
Retrieves a single field value by its name.
override
getChildrenByName(String fieldName, [bool checkValid = false]) List<FhirBase>
Retrieves all matching child fields by name. Optionally validates the name.
override
hasType(List<String> names) bool
Checks if the object has a given type.
inherited
hasValues() bool
Checks if the object has values.
inherited
isAs<T extends FhirBase>() → T?
Returns an Object cast as a Type if it is that type.
inherited
isEmpty() bool
Checks if the object is empty.
inherited
listChildrenNames() List<String>
Lists the JSON keys for the object.
override
listEquals<T extends FhirBase>(List<T>? list1, List<T>? list2) bool
Compares two lists of FhirBase objects for equality. Returns true if both lists are null, or if they have the same length and all corresponding elements are deeply equal.
inherited
newId() Resource
returns the same resource with a new ID (even if there is already an ID present)
inherited
newIdIfNoId() Resource
returns the same resource with a new ID if there is no current ID
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint() String
Converts the object to a pretty JSON string.
inherited
toJson() Map<String, dynamic>
Returns a Map<String, dynamic> of the DomainResource
override
toJsonString() String
Converts the object to a JSON string.
inherited
toString() String
A string representation of this object.
inherited
toYaml() String
Converts the object to a YAML string.
inherited
updateVersion({FhirMeta? oldMeta, bool versionIdAsTime = false}) Resource
Updates the meta field of this Resource, updates the meta.lastUpdated field, adds 1 to the version number
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited