InvoicePriceComponent class

InvoicePriceComponent The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.

Inheritance
Available extensions

Constructors

InvoicePriceComponent({FhirString? id, List<FhirExtension>? extension_, List<FhirExtension>? modifierExtension, required InvoicePriceComponentType type, CodeableConcept? code, FhirDecimal? factor, Money? amount, bool? disallowExtensions = false})
Primary constructor for InvoicePriceComponent
const
InvoicePriceComponent.fromJson(Map<String, dynamic> json)
Factory constructor that accepts Map<String, dynamic> as an argument
factory
InvoicePriceComponent.fromJsonString(String source)
Factory constructor for InvoicePriceComponent that takes in a String Convenience method to avoid the json Encoding/Decoding normally required to get data from a String
factory
InvoicePriceComponent.fromYaml(dynamic yaml)
Deserialize InvoicePriceComponent from a String or YamlMap object
factory

Properties

amount Money?
amount The amount calculated for this component.
final
code CodeableConcept?
code A code that identifies the component. Codes may be used to differentiate between kinds of taxes, surcharges, discounts etc.
final
copyWith $InvoicePriceComponentCopyWith<InvoicePriceComponent>
Copy function for InvoicePriceComponent Returns a copy of the current instance with the provided fields modified. If a field is not provided, it will retain its original value. If a null is provided, this will clearn the field, unless the field is required, in which case it will keep its current value.
no setteroverride
copyWith $InvoicePriceComponentCopyWith<InvoicePriceComponent>

Available on InvoicePriceComponent, provided by the InvoicePriceComponentCopyWithExtension extension

no setter
disallowExtensions bool?
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
finalinherited
extension_ List<FhirExtension>?
List of extensions for additional information.
finalinherited
factor FhirDecimal?
factor The factor that has been applied on the base price for calculating this component.
final
fhirType String
Returns the FHIR type of the object.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasId bool
Getter for checking if the element has an id.
no setterinherited
hasPrimitiveValue bool
Checks if the object has a primitive value.
no setterinherited
id FhirString?
Unique id for the element within a resource.
finalinherited
isMetadataBased bool
All Elements are metadata based.
no setterinherited
isPrimitive bool
Checks if the object is primitive.
no setterinherited
modifierExtension List<FhirExtension>?
List of modifier extensions for additional, non-core information
finalinherited
primitiveValue String?
Retrieves the primitive value of the object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type InvoicePriceComponentType
type This code identifies the type of the component.
final

Methods

addExtension(FhirExtension ext) → void
Method to add an extension.
inherited
addModifierExtension(FhirExtension ext) → void
Adds a modifier extension
inherited
clone() InvoicePriceComponent
Subclasses must implement the clone method.
override
compareDeep(FhirBase? e1, FhirBase? e2, [bool allowNull = false]) bool
Compares two FhirBase objects deeply using JSON comparison. This method converts both objects to JSON and compares the resulting structures, which catches all differences including those in nested objects.
inherited
compareDeepLists<T extends FhirBase>(List<T>? e1, List<T>? e2, bool allowNull) bool
Compares two lists with optional null/empty handling.
inherited
compareDeepStrings(String? s1, String? s2, bool allowNull) bool
Checks if the object is equal to another object.
inherited
equalsDeep(FhirBase? o) bool
Performs a deep comparison between two instances.
override
equalsDeepWithNull(FhirBase? obj1, FhirBase? obj2) bool
Deeply compares two FhirBase objects, either of which can be null. This is a convenience method that handles null checking before calling equalsDeep.
inherited
equalsShallow(Element other) bool
Method to compare shallow equality of two elements.
inherited
getChildByName(String name) FhirBase?
Retrieves a single field value by its name.
override
getChildrenByName(String fieldName, [bool checkValid = false]) List<FhirBase>
Retrieves all matching child fields by name. Optionally validates the name.
override
getExtensionFirstRep() FhirExtension
Getter for the first extension.
inherited
getExtensionsByUrl(String url) List<FhirExtension>
Getter for the first extension by url.
inherited
getModifierExtensionFirstRep() FhirExtension
Gets the first repetition of modifier extensions
inherited
getModifierExtensionsByUrl(String url) List<FhirExtension>
Retrieves all modifier extensions by URL
inherited
hasExtension() bool
Extension handling methods.
inherited
hasExtensionByUrl(String url) bool
Method to check if an extension exists by url.
inherited
hasModifierExtension() bool
Method to check if there are any modifier extensions
inherited
hasType(List<String> names) bool
Checks if the object has a given type.
inherited
hasValues() bool
Checks if the object has values.
inherited
isAs<T extends FhirBase>() → T?
Returns an Object cast as a Type if it is that type.
inherited
isEmpty() bool
Checks if the object is empty.
inherited
listChildrenNames() List<String>
Lists the JSON keys for the object.
override
listEquals<T extends FhirBase>(List<T>? list1, List<T>? list2) bool
Compares two lists of FhirBase objects for equality. Returns true if both lists are null, or if they have the same length and all corresponding elements are deeply equal.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint() String
Converts the object to a pretty JSON string.
inherited
removeExtension(String url) → void
Method to remove an extension by url.
inherited
removeModifierExtension(String url) → void
Removes modifier extensions by URL
inherited
toJson() Map<String, dynamic>
Converts the object to a JSON representation.
override
toJsonString() String
Converts the object to a JSON string.
inherited
toString() String
A string representation of this object.
inherited
toYaml() String
Converts the object to a YAML string.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited